@@ -11,35 +11,46 @@
 ## - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - |
 #     Partition a dataset
 ## - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - |
-
-partition = function( data, prob = c( 0.7, 0.3 ), set.seed = NULL )
+   
+partition = function(data, prob = c(0.7, 0.3), set.seed = NULL)
 {
-    if( !is.matrix( data ) & !is.data.frame( data ) ) stop( " data must be a matrix, or dataframe" )
+    if(!is.matrix(data) & !is.data.frame(data)) 
+        stop(" data must be a matrix, or dataframe")
     
-    if( !is.null( set.seed ) ) set.seed( set.seed )
+    if(sum(prob) > 1) 
+        stop(" Sum of the vector 'prob' must be smaller or equal to 1")
+    else if(sum(prob) < 1)
+        prob = c(prob, 1 - sum(prob))
     
-    length_prob = length( prob )
+    length_prob = length(prob)
+    length_data = nrow(data)
     
-    if( length_prob > nrow( data ) ) stop( "length of prob must be smaller or equal to number of observations." )
+    if(length_prob > nrow(data)) 
+        stop(" length of prob must be smaller or equal to number of observations.")
     
-    ind = sample( length_prob, nrow( data ), replace = TRUE, prob = prob )
+    if(!is.null(set.seed)) 
+        set.seed(set.seed)
     
-    if( length_prob == 1 ){
-        partitions = data[ ind == 1, ]
-    }else{
-        name_list = vector( length = length_prob )
-        partitions = list()
+    name_list = vector(length = length_prob)
+    partitions = list()
+    
+    for(i in 1:(length_prob - 1))
+    {
+        ind_i = sample(1:length_data, size = round(prob[i] * length_data), replace = F)
         
-        for( i in 1:length_prob ){
-            partitions[[ i ]] = data[ ind == i, ]
-            
-            name_list[ i ] = paste( c( "part", i ), collapse = "" )
-        }
+        partitions[[i]] = data[ind_i,]
         
-        names( partitions ) = name_list
+        data        = data[-ind_i,]
+        length_data = nrow(data)
+        name_list[i] = paste(c("part", i), collapse = "")
     }
     
-    return( partitions )    
+    partitions[[length_prob]] = data
+    name_list[length_prob] = paste(c("part", length_prob), collapse = "")
+    
+    names(partitions) = name_list
+    
+    return(partitions)    
 }
    
 ## - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - |
