@@ -12,14 +12,17 @@
 #     Z-score normalization
 ## - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - |
 
-transform = function( x, method = c( "minmax", "zscore" ), columns = NULL, na.rm = FALSE ) 
+transform = function(x, method = c("minmax", "zscore"), columns = NULL, na.rm = FALSE) 
 {
-    method = match.arg( method )
+    method = match.arg(method)
     
-    if( method == "minmax" ) x_trans = liver::minmax( x = x, columns = columns, na.rm = na.rm )
-    if( method == "zscore" ) x_trans = liver::zscore( x = x, columns = columns, na.rm = na.rm )
+    if(method == "minmax") 
+		x_trans = liver::minmax(x = x, columns = columns, na.rm = na.rm)
+		
+    if(method == "zscore") 
+		x_trans = liver::zscore(x = x, columns = columns, na.rm = na.rm)
     
-    return( x_trans )
+    return(x_trans)
 }
 
 ## - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - |
